==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/ja.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開リンク",
    "Photos" : "写真",
    "Your memories under your control" : "あなたの思い出はあなたが管理しましょう",
    "All media" : "すべて",
    "Videos" : "動画",
    "Albums" : "アルバム",
    "Collaborative albums" : "共有アルバム",
    "Folders" : "フォルダー",
    "Favorites" : "お気に入り",
    "On this day" : "この日",
    "Shared with you" : "共有中",
    "Tags" : "タグ",
    "Mark selection as favorite" : "選択したものをお気に入りとしてマーク",
    "Add selection to favorites" : "選択したものをお気に入りに追加",
    "Remove selection from favorites" : "選択したものをお気に入りから削除",
    "Name of the album" : "アルバム名",
    "Location of the album" : "アルバムの場所",
    "Go back to the previous view." : "前を表示",
    "Back" : "戻る",
    "Add collaborators" : "共有者に追加",
    "Save." : "保存",
    "Create the album." : "アルバムを作成",
    "Save" : "保存",
    "Create album" : "アルバムを作成",
    "Add to Album" : "アルバムに追加",
    "Create a new album." : "新しいアルバムを作成",
    "Create new album" : "新しいアルバムを作成",
    "Copy public link" : "公開リンクをコピー",
    "An error occurred" : "エラーが発生しました",
    "Open the full size \"{name}\" image" : "画像 \"{name}\" をフルサイズで開く",
    "Open the \"{name}\" sub-directory" : "サブディレクトリ \"{name}\" を開く",
    "Back to {folder}" : " {folder} に戻る",
    "Share this folder" : "このフォルダーを共有する",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "写真を矩形での表示を有効化",
    "View" : "表示",
    "Favorite" : "お気に入り",
    "Remove from favorites" : "お気に入りから削除",
    "This folder does not exist" : "このフォルダーは存在しません",
    "No photos in here" : "写真がありません",
    "Shared by" : "共有者",
    "Shared albums" : "共有アルバム",
    "No tags yet" : "まだタグがありません",
    "Photos with tags will show up here" : "タグ付けされた写真がここに表示されます",
    "Add" : "追加",
    "Delete selection" : "選択した項目を削除",
    "Tagged photos" : "タグ付けされた写真",
    "Your photos" : "写真",
    "Your videos" : "動画",
    "Your folders" : "フォルダー",
    "Locations" : "場所",
    "Settings" : "設定"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/ja.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開リンク",
    "Photos" : "写真",
    "Your memories under your control" : "あなたの思い出はあなたが管理しましょう",
    "All media" : "すべて",
    "Videos" : "動画",
    "Albums" : "アルバム",
    "Collaborative albums" : "共有アルバム",
    "Folders" : "フォルダー",
    "Favorites" : "お気に入り",
    "On this day" : "この日",
    "Shared with you" : "共有中",
    "Tags" : "タグ",
    "Mark selection as favorite" : "選択したものをお気に入りとしてマーク",
    "Add selection to favorites" : "選択したものをお気に入りに追加",
    "Remove selection from favorites" : "選択したものをお気に入りから削除",
    "Name of the album" : "アルバム名",
    "Location of the album" : "アルバムの場所",
    "Go back to the previous view." : "前を表示",
    "Back" : "戻る",
    "Add collaborators" : "共有者に追加",
    "Save." : "保存",
    "Create the album." : "アルバムを作成",
    "Save" : "保存",
    "Create album" : "アルバムを作成",
    "Add to Album" : "アルバムに追加",
    "Shared by" : "共有者",
    "Create a new album." : "新しいアルバムを作成",
    "Create new album" : "新しいアルバムを作成",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "Copy public link" : "公開リンクをコピー",
    "An error occurred" : "エラーが発生しました",
    "Open the full size \"{name}\" image" : "画像 \"{name}\" をフルサイズで開く",
    "Open the \"{name}\" sub-directory" : "サブディレクトリ \"{name}\" を開く",
    "Back to {folder}" : " {folder} に戻る",
    "Share this folder" : "このフォルダーを共有する",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "写真を矩形での表示を有効化",
    "Invalid location selected" : "選択した場所が無効",
    "View" : "表示",
    "Unselect all" : "すべて選択解除",
    "Favorite" : "お気に入り",
    "Remove from favorites" : "お気に入りから削除",
    "This folder does not exist" : "このフォルダーは存在しません",
    "No photos in here" : "写真がありません",
    "No tags yet" : "まだタグがありません",
    "Photos with tags will show up here" : "タグ付けされた写真がここに表示されます",
    "Add" : "追加",
    "Delete selection" : "選択した項目を削除",
    "Tagged photos" : "タグ付けされた写真",
    "Locations" : "場所",
    "Shared albums" : "共有アルバム"
},
"nplurals=1; plural=0;");
